@@ -17,7 +17,7 @@ using namespace apolloron;
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "2.0.4";
+const char *INKF_VERSION  = "2.0.5";
 const char *INKF_COPY     = "Copyright (C) 2002-2018 Masashi Astro Tachibana";
 const char *INKF_DEF_OUT  = "inkf.out";
 
@@ -209,6 +209,27 @@ int main(int argc, char *argv[]) {
                 tmp_str = hc.getURL(option.input_filenames[i]);
                 strncpy(option.input_charset, hc.getOrigCharset().c_str(), 31);
                 option.input_charset[31] = '\0';
+            } else if (!strncasecmp(option.input_filenames[i], "ftp://", 6)) {
+                FTPStream fs;
+                String host;
+                String port = 21;
+                String path;
+                long x;
+                host = option.input_filenames[i]+6;
+                x = host.search(":");
+                if (0 <= x) {
+                    host = host.mid(0, x);
+                }
+                x = host.search("/");
+                if (0 <= x) {
+                    path = host.mid(x);
+                    host = host.mid(0, x);
+                }
+                if (fs.login("anonymous", "user@example.com", host, port)) {
+                    fs.passive();
+                    tmp_str = fs.receiveBuffer(path);
+                    fs.logout();
+                }
             } else {
                 tmp_str.loadFile(option.input_filenames[i]);
             }
