@@ -35,12 +35,12 @@ static const char rcsid[] = "$Id: fcgiapp.c,v 1.34 2001/12/12 22:54:10 robs Exp
 #include <unistd.h>
 #include <limits.h>
 
+#include "fcgiapp.h"
 #include "apolloron.h"
 
 #include "fcgimisc.h"
 #include "fastcgi.h"
 #include "fcgios.h"
-#include "fcgiapp.h"
 
 #define LONG_DOUBLE long double
 
@@ -391,7 +391,7 @@ static void CopyAndAdvance(char **destPtr, char **srcPtr, int n);
 int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
 {
     char *f, *fStop, *percentPtr, *p, *fmtBuffPtr, *buffPtr;
-    int op, performedOp, sizeModifier, buffCount = 0, buffLen, specifierLength;
+    int op, performedOp, sizeModifier, buffCount = 0, /* buffLen, */ specifierLength;
     int fastPath, n, auxBuffLen = 0, buffReqd, minWidth, precision, exp;
     char *auxBuffPtr = NULL;
     int streamCount = 0;
@@ -462,7 +462,7 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                         break;
                 }
                 buffPtr = buff;
-                buffLen = PRINTF_BUFFLEN;
+                /* buffLen = PRINTF_BUFFLEN; */
             } else {
                 /*
                  * Slow path: Scan the conversion specifier and construct
@@ -618,7 +618,7 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                  */
                 if(buffReqd <= PRINTF_BUFFLEN) {
                     buffPtr = buff;
-                    buffLen = PRINTF_BUFFLEN;
+                    /* buffLen = PRINTF_BUFFLEN; */
                 } else {
                     if(auxBuffPtr == NULL || buffReqd > auxBuffLen) {
                         if(auxBuffPtr != NULL) free(auxBuffPtr);
@@ -628,7 +628,7 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                             goto ErrorReturn;
                     }
                     buffPtr = auxBuffPtr;
-                    buffLen = auxBuffLen;
+                    /* buffLen = auxBuffLen; */
                 }
             }
             /*
@@ -715,7 +715,7 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                             if(fastPath) {
                                 buffPtr = va_arg(arg, char *);
                                 buffCount = strlen(buffPtr);
-                                buffLen = buffCount + 1;
+                                /* buffLen = buffCount + 1; */
                             } else {
                                 sprintf(buffPtr, fmtBuff, charPtrArg);
                                 buffCount = strlen(buffPtr);
